#####################
Changes in glymur 0.9
#####################

****************
Changes in 0.9.9
****************

    * Fix bug retrieving some TIFF tags on big endian systems.

****************
Changes in 0.9.8
****************

    * Fix install requirements.

****************
Changes in 0.9.7
****************

    * Remove distutils in favor of setuptools.
    * Add recognition of IMF profiles.
    * Add ndim, dtype properties.

****************
Changes in 0.9.6
****************

    * Fix tiff support on windows.
    * Update doc support for python 3.10.

****************
Changes in 0.9.5
****************

    * Add support for generation of PLT markers.
    * Add support for converting TIFFs to JPEG 2000.
    * Add recognition of additional IMF profiles.

****************
Changes in 0.9.4
****************

    * Remove support for Python 3.6.
    * Add support for writing images tile-by-tile.
    * Add support for opj_set_decoded_components.

****************
Changes in 0.9.3
****************

    * Qualify on Python 3.9
    * Qualify on OpenJPEG 2.4.0
    * Add support for multithreaded writes.

****************
Changes in 0.9.2
****************

    * Update setup.py to include tests in source distribution to PyPi.
    * Update gdal imports to comply with GDAL recommendations.

****************
Changes in 0.9.1
****************

    * Remove gdal from setup.py requirements as it is optional.
    * Add Travis-CI case for missing GDAL.

****************
Changes in 0.9.0
****************

    * Restricted to Python 3.6 and more recent.  If you are still using Python 2.7, you should remain with the 0.8.x series.
    * Restricted to OpenJPEG version 2.3.x and higher.  If you still need to use older versions of OpenJPEG, you should remain with with 0.8.x series.
    * Backwards incompatibility: the read_bands method no longer takes the layer argument, you must set this using the layer property.
    * Backwards incompatibility: the icc_profile member of the ColourSpecificationBox is no longer a dictionary of metadata, but is instead a series of raw bytes that may be read by any software capable of interpreting ICC profiles.  The dictionary of metadata has been renamed to "icc_profile_header".
    * lxml is no longer an optional dependency.
